Version 2.1
: Fixes a bug when connecting to Marty V1

Version 2.0
: Added Marty V2 support
: Removed unnecessary imports
: Dropped Python 2 support

Version 1.2
: Addresses security issues in `requests` and `urllib3` dependencies

Version 1.1
: Adds ROSClient and Distance Sensor support

Version 1.0
: SocketClient and TestClient provided

Version 0.0.1 (Alpha)
: Adds initial API implementation for Socket-based control. Adds client class structure
